@@ -47,7 +47,7 @@ struct data1_handle_info {
 
 data1_handle data1_create(void)
 {
-    data1_handle p = (data1_handle)xmalloc (sizeof(*p));
+    data1_handle p = (data1_handle)xmalloc(sizeof(*p));
     if (!p)
         return 0;
     p->tab_path = NULL;
@@ -59,26 +59,26 @@ data1_handle data1_create(void)
     p->map_len = 0;
     p->absyn_cache = NULL;
     p->attset_cache = NULL;
-    p->mem = nmem_create ();
+    p->mem = nmem_create();
     return p;
 }
 
-NMEM data1_nmem_get (data1_handle dh)
+NMEM data1_nmem_get(data1_handle dh)
 {
     return dh->mem;
 }
 
-data1_absyn_cache *data1_absyn_cache_get (data1_handle dh)
+data1_absyn_cache *data1_absyn_cache_get(data1_handle dh)
 {
     return &dh->absyn_cache;
 }
 
-data1_attset_cache *data1_attset_cache_get (data1_handle dh)
+data1_attset_cache *data1_attset_cache_get(data1_handle dh)
 {
     return &dh->attset_cache;
 }
 
-void data1_destroy (data1_handle dh)
+void data1_destroy(data1_handle dh)
 {
     if (!dh)
         return;
@@ -90,65 +90,61 @@ void data1_destroy (data1_handle dh)
     data1_absyn_destroy(dh);
 
     wrbuf_destroy(dh->wrbuf);
-    if (dh->tab_path)
-        xfree (dh->tab_path);
-    if (dh->tab_root)
-        xfree (dh->tab_root);
-    if (dh->read_buf)
-        xfree (dh->read_buf);
-    if (dh->map_buf)
-        xfree (dh->map_buf);
-    nmem_destroy (dh->mem);
+    xfree(dh->tab_path);
+    xfree(dh->tab_root);
+    xfree(dh->read_buf);
+    xfree(dh->map_buf);
+    nmem_destroy(dh->mem);
 
-    xfree (dh);
+    xfree(dh);
 }
 
-WRBUF data1_get_wrbuf (data1_handle dp)
+WRBUF data1_get_wrbuf(data1_handle dp)
 {
     return dp->wrbuf;
 }
 
-char **data1_get_read_buf (data1_handle dp, int **lenp)
+char **data1_get_read_buf(data1_handle dp, int **lenp)
 {
     *lenp = &dp->read_len;
-    yaz_log (YLOG_DEBUG, "data1_get_read_buf lenp=%u", **lenp);
+    yaz_log(YLOG_DEBUG, "data1_get_read_buf lenp=%u", **lenp);
     return &dp->read_buf;
 }
 
-char **data1_get_map_buf (data1_handle dp, int **lenp)
+char **data1_get_map_buf(data1_handle dp, int **lenp)
 {
     *lenp = &dp->map_len;
-    yaz_log (YLOG_DEBUG, "data1_get_map_buf lenp=%u", **lenp);
+    yaz_log(YLOG_DEBUG, "data1_get_map_buf lenp=%u", **lenp);
     return &dp->map_buf;
 }
 
-void data1_set_tabpath (data1_handle dp, const char *p)
+void data1_set_tabpath(data1_handle dp, const char *p)
 {
-    xfree (dp->tab_path);
+    xfree(dp->tab_path);
     dp->tab_path = NULL;
     if (p)
         dp->tab_path = xstrdup (p);
 }
 
-void data1_set_tabroot (data1_handle dp, const char *p)
+void data1_set_tabroot(data1_handle dp, const char *p)
 {
-    xfree (dp->tab_root);
+    xfree(dp->tab_root);
     dp->tab_root = NULL;
     if (p)
-        dp->tab_root = xstrdup (p);
+        dp->tab_root = xstrdup(p);
 }
 
-const char *data1_get_tabpath (data1_handle dp)
+const char *data1_get_tabpath(data1_handle dp)
 {
     return dp->tab_path;
 }
 
-const char *data1_get_tabroot (data1_handle dp)
+const char *data1_get_tabroot(data1_handle dp)
 {
     return dp->tab_root;
 }
 
-FILE *data1_path_fopen (data1_handle dh, const char *file, const char *mode)
+FILE *data1_path_fopen(data1_handle dh, const char *file, const char *mode)
 {
     FILE *f;
     const char *path = data1_get_tabpath(dh);
