@@ -29,10 +29,11 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #include <stdio.h>
 #include <stdlib.h>
 
+#include <yaz/snprintf.h>
 #include <yaz/yaz-util.h>
 #include <d1_absyn.h>
 
-data1_node *data1_get_root_tag (data1_handle dh, data1_node *n)
+data1_node *data1_get_root_tag(data1_handle dh, data1_node *n)
 {
     if (!n)
         return 0;
@@ -49,7 +50,7 @@ data1_node *data1_get_root_tag (data1_handle dh, data1_node *n)
  * get the tag which is the immediate parent of this node (this may mean
  * traversing intermediate things like variants and stuff.
  */
-data1_node *get_parent_tag (data1_handle dh, data1_node *n)
+data1_node *get_parent_tag(data1_handle dh, data1_node *n)
 {
     if (data1_is_xmlmode(dh))
     {
@@ -67,17 +68,17 @@ data1_node *get_parent_tag (data1_handle dh, data1_node *n)
     return 0;
 }
 
-data1_node *data1_mk_node (data1_handle dh, NMEM m)
+data1_node *data1_mk_node(data1_handle dh, NMEM m)
 {
-    return data1_mk_node2 (dh, m, DATA1N_root, 0);
+    return data1_mk_node2(dh, m, DATA1N_root, 0);
 }
 
-data1_node *data1_mk_node_type (data1_handle dh, NMEM m, int type)
+data1_node *data1_mk_node_type(data1_handle dh, NMEM m, int type)
 {
-    return data1_mk_node2 (dh, m, type, 0);
+    return data1_mk_node2(dh, m, type, 0);
 }
 
-static void data1_init_node (data1_handle dh, data1_node *r, int type)
+static void data1_init_node(data1_handle dh, data1_node *r, int type)
 {
     r->which = type;
     switch(type)
@@ -116,12 +117,12 @@ static void data1_init_node (data1_handle dh, data1_node *r, int type)
         r->u.preprocess.attributes = 0;
         break;
     default:
-        yaz_log (YLOG_WARN, "data_mk_node_type. bad type = %d\n", type);
+        yaz_log(YLOG_WARN, "data_mk_node_type. bad type = %d\n", type);
     }
 }
 
-data1_node *data1_append_node (data1_handle dh, NMEM m, int type,
-                               data1_node *parent)
+data1_node *data1_append_node(data1_handle dh, NMEM m, int type,
+                              data1_node *parent)
 {
     data1_node *r = (data1_node *)nmem_malloc(m, sizeof(*r));
     r->next = r->child = r->last_child = 0;
@@ -142,14 +143,14 @@ data1_node *data1_append_node (data1_handle dh, NMEM m, int type,
     return r;
 }
 
-data1_node *data1_mk_node2 (data1_handle dh, NMEM m, int type,
-                            data1_node *parent)
+data1_node *data1_mk_node2(data1_handle dh, NMEM m, int type,
+                           data1_node *parent)
 {
-    return data1_append_node (dh, m, type, parent);
+    return data1_append_node(dh, m, type, parent);
 }
 
-data1_node *data1_insert_node (data1_handle dh, NMEM m, int type,
-                               data1_node *parent)
+data1_node *data1_insert_node(data1_handle dh, NMEM m, int type,
+                              data1_node *parent)
 {
     data1_node *r = (data1_node *)nmem_malloc(m, sizeof(*r));
     r->next = r->child = r->last_child = 0;
@@ -170,7 +171,7 @@ data1_node *data1_insert_node (data1_handle dh, NMEM m, int type,
     return r;
 }
 
-data1_node *data1_mk_root (data1_handle dh, NMEM nmem, const char *name)
+data1_node *data1_mk_root(data1_handle dh, NMEM nmem, const char *name)
 {
     data1_absyn *absyn = data1_get_absyn(dh, name, 1);
     data1_node *res;
@@ -181,8 +182,8 @@ data1_node *data1_mk_root (data1_handle dh, NMEM nmem, const char *name)
                 name);
         /* It's now OK for a record not to have an absyn */
     }
-    res = data1_mk_node2 (dh, nmem, DATA1N_root, 0);
-    res->u.root.type = data1_insert_string (dh, res, nmem, name);
+    res = data1_mk_node2(dh, nmem, DATA1N_root, 0);
+    res->u.root.type = data1_insert_string(dh, res, nmem, name);
     res->u.root.absyn = absyn;
     return res;
 }
@@ -193,7 +194,7 @@ void data1_set_root(data1_handle dh, data1_node *res,
     data1_absyn *absyn = data1_get_absyn(
         dh, name, DATA1_XPATH_INDEXING_ENABLE);
 
-    res->u.root.type = data1_insert_string (dh, res, nmem, name);
+    res->u.root.type = data1_insert_string(dh, res, nmem, name);
     res->u.root.absyn = absyn;
 }
 
@@ -205,9 +206,9 @@ void data1_add_attrs(data1_handle dh, NMEM nmem, const char **attr,
 
     while (attr && *attr)
     {
-        *p = (data1_xattr*) nmem_malloc (nmem, sizeof(**p));
-        (*p)->name = nmem_strdup (nmem, *attr++);
-        (*p)->value = nmem_strdup (nmem, *attr++);
+        *p = (data1_xattr*) nmem_malloc(nmem, sizeof(**p));
+        (*p)->name = nmem_strdup(nmem, *attr++);
+        (*p)->value = nmem_strdup(nmem, *attr++);
         (*p)->what = DATA1I_text;
 
         p = &(*p)->next;
@@ -215,66 +216,66 @@ void data1_add_attrs(data1_handle dh, NMEM nmem, const char **attr,
     *p = 0;
 }
 
-data1_node *data1_mk_preprocess (data1_handle dh, NMEM nmem,
-                                 const char *target,
-                                 const char **attr, data1_node *at)
+data1_node *data1_mk_preprocess(data1_handle dh, NMEM nmem,
+                                const char *target,
+                                const char **attr, data1_node *at)
 {
-    return data1_mk_preprocess_n (dh, nmem, target, strlen(target),
+    return data1_mk_preprocess_n(dh, nmem, target, strlen(target),
                                   attr, at);
 }
 
-data1_node *data1_mk_preprocess_n (data1_handle dh, NMEM nmem,
-                                   const char *target, size_t len,
-                                   const char **attr, data1_node *at)
+data1_node *data1_mk_preprocess_n(data1_handle dh, NMEM nmem,
+                                  const char *target, size_t len,
+                                  const char **attr, data1_node *at)
 {
-    data1_node *res = data1_mk_node2 (dh, nmem, DATA1N_preprocess, at);
-    res->u.preprocess.target = data1_insert_string_n (dh, res, nmem,
+    data1_node *res = data1_mk_node2(dh, nmem, DATA1N_preprocess, at);
+    res->u.preprocess.target = data1_insert_string_n(dh, res, nmem,
                                                       target, len);
 
     data1_add_attrs(dh, nmem, attr, &res->u.preprocess.attributes);
     return res;
 }
 
-data1_node *data1_insert_preprocess (data1_handle dh, NMEM nmem,
+data1_node *data1_insert_preprocess(data1_handle dh, NMEM nmem,
                                  const char *target,
                                  const char **attr, data1_node *at)
 {
-    return data1_insert_preprocess_n (dh, nmem, target, strlen(target),
+    return data1_insert_preprocess_n(dh, nmem, target, strlen(target),
                                       attr, at);
 }
 
-data1_node *data1_insert_preprocess_n (data1_handle dh, NMEM nmem,
+data1_node *data1_insert_preprocess_n(data1_handle dh, NMEM nmem,
                                    const char *target, size_t len,
                                    const char **attr, data1_node *at)
 {
-    data1_node *res = data1_insert_node (dh, nmem, DATA1N_preprocess, at);
-    res->u.preprocess.target = data1_insert_string_n (dh, res, nmem,
+    data1_node *res = data1_insert_node(dh, nmem, DATA1N_preprocess, at);
+    res->u.preprocess.target = data1_insert_string_n(dh, res, nmem,
                                                       target, len);
 
     data1_add_attrs(dh, nmem, attr, &res->u.preprocess.attributes);
     return res;
 }
 
-data1_node *data1_mk_tag_n (data1_handle dh, NMEM nmem,
-                            const char *tag, size_t len, const char **attr,
-                            data1_node *at)
+data1_node *data1_mk_tag_n(data1_handle dh, NMEM nmem,
+                           const char *tag, size_t len, const char **attr,
+                           data1_node *at)
 {
     data1_node *partag = get_parent_tag(dh, at);
-    data1_node *res = data1_mk_node2 (dh, nmem, DATA1N_tag, at);
+    data1_node *res = data1_mk_node2(dh, nmem, DATA1N_tag, at);
     data1_element *e = 0;
 
-    res->u.tag.tag = data1_insert_string_n (dh, res, nmem, tag, len);
+    res->u.tag.tag = data1_insert_string_n(dh, res, nmem, tag, len);
 
     if (!partag)  /* top tag? */
-        e  = data1_getelementbytagname (dh, at->root->u.root.absyn,
-                                        0 /* index as local */,
-                                        res->u.tag.tag);
+        e  = data1_getelementbytagname(dh, at->root->u.root.absyn,
+                                       0 /* index as local */,
+                                       res->u.tag.tag);
     else
     {
         /* only set element for known tags */
         e = partag->u.tag.element;
         if (e)
-            e = data1_getelementbytagname (dh, at->root->u.root.absyn,
+            e = data1_getelementbytagname(dh, at->root->u.root.absyn,
                                            e, res->u.tag.tag);
     }
     res->u.tag.element = e;
@@ -282,8 +283,8 @@ data1_node *data1_mk_tag_n (data1_handle dh, NMEM nmem,
     return res;
 }
 
-void data1_tag_add_attr (data1_handle dh, NMEM nmem,
-                         data1_node *res, const char **attr)
+void data1_tag_add_attr(data1_handle dh, NMEM nmem,
+                        data1_node *res, const char **attr)
 {
     if (res->which != DATA1N_tag)
         return;
@@ -291,102 +292,125 @@ void data1_tag_add_attr (data1_handle dh, NMEM nmem,
     data1_add_attrs(dh, nmem, attr, &res->u.tag.attributes);
 }
 
-data1_node *data1_mk_tag (data1_handle dh, NMEM nmem,
-                          const char *tag, const char **attr, data1_node *at)
+data1_node *data1_mk_tag(data1_handle dh, NMEM nmem,
+                         const char *tag, const char **attr, data1_node *at)
 {
-    return data1_mk_tag_n (dh, nmem, tag, strlen(tag), attr, at);
+    return data1_mk_tag_n(dh, nmem, tag, strlen(tag), attr, at);
 }
 
-data1_node *data1_search_tag (data1_handle dh, data1_node *n,
-                              const char *tag)
+data1_node *data1_search_tag(data1_handle dh, data1_node *n,
+                             const char *tag)
 {
     if (*tag == '/')
     {
-        n = data1_get_root_tag (dh, n);
+        n = data1_get_root_tag(dh, n);
         if (n)
             n = n->child;
         tag++;
     }
     for (; n; n = n->next)
         if (n->which == DATA1N_tag && n->u.tag.tag &&
-            !yaz_matchstr (n->u.tag.tag, tag))
+            !yaz_matchstr(n->u.tag.tag, tag))
         {
             return n;
         }
     return 0;
 }
 
-data1_node *data1_mk_tag_uni (data1_handle dh, NMEM nmem,
-                              const char *tag, data1_node *at)
+data1_node *data1_mk_tag_uni(data1_handle dh, NMEM nmem,
+                             const char *tag, data1_node *at)
 {
-    data1_node *node = data1_search_tag (dh, at->child, tag);
+    data1_node *node = data1_search_tag(dh, at->child, tag);
     if (!node)
-        node = data1_mk_tag (dh, nmem, tag, 0 /* attr */, at);
+        node = data1_mk_tag(dh, nmem, tag, 0 /* attr */, at);
     else
         node->child = node->last_child = 0;
     return node;
 }
 
-data1_node *data1_mk_text_n (data1_handle dh, NMEM mem,
-                             const char *buf, size_t len, data1_node *parent)
+data1_node *data1_mk_text_n(data1_handle dh, NMEM mem,
+                            const char *buf, size_t len, data1_node *parent)
 {
-    data1_node *res = data1_mk_node2 (dh, mem, DATA1N_data, parent);
-    res->u.data.what = DATA1I_text;
-    res->u.data.len = len;
-
-    res->u.data.data = data1_insert_string_n (dh, res, mem, buf, len);
+    data1_node *res = data1_mk_node2(dh, mem, DATA1N_data, parent);
+    data1_set_data_string_n(dh, res, mem, buf, len);
     return res;
 }
 
-data1_node *data1_mk_text_nf (data1_handle dh, NMEM mem,
-                              const char *buf, size_t len, data1_node *parent)
+data1_node *data1_mk_text_nf(data1_handle dh, NMEM mem,
+                             const char *buf, size_t len, data1_node *parent)
 {
-    data1_node *res = data1_mk_text_n (dh, mem, buf, len, parent);
+    data1_node *res = data1_mk_text_n(dh, mem, buf, len, parent);
     res->u.data.formatted_text = 1;
     return res;
 }
 
-data1_node *data1_mk_text (data1_handle dh, NMEM mem,
-                           const char *buf, data1_node *parent)
+data1_node *data1_mk_text(data1_handle dh, NMEM mem,
+                          const char *buf, data1_node *parent)
 {
-    return data1_mk_text_n (dh, mem, buf, strlen(buf), parent);
+    return data1_mk_text_n(dh, mem, buf, strlen(buf), parent);
 }
 
-data1_node *data1_mk_comment_n (data1_handle dh, NMEM mem,
-                                const char *buf, size_t len,
-                                data1_node *parent)
+data1_node *data1_mk_comment_n(data1_handle dh, NMEM mem,
+                               const char *buf, size_t len,
+                               data1_node *parent)
 {
-    data1_node *res = data1_mk_node2 (dh, mem, DATA1N_comment, parent);
-    res->u.data.what = DATA1I_text;
-    res->u.data.len = len;
-
-    res->u.data.data = data1_insert_string_n (dh, res, mem, buf, len);
+    data1_node *res = data1_mk_node2(dh, mem, DATA1N_comment, parent);
+    data1_set_data_string_n(dh, res, mem, buf, len);
     return res;
 }
 
-data1_node *data1_mk_comment (data1_handle dh, NMEM mem,
-                              const char *buf, data1_node *parent)
+data1_node *data1_mk_comment(data1_handle dh, NMEM mem,
+                             const char *buf, data1_node *parent)
 {
-    return data1_mk_comment_n (dh, mem, buf, strlen(buf), parent);
+    return data1_mk_comment_n(dh, mem, buf, strlen(buf), parent);
 }
 
-char *data1_insert_string_n (data1_handle dh, data1_node *res,
-                             NMEM m, const char *str, size_t len)
+void data1_set_data_string_n(data1_handle dh, data1_node *res, NMEM m,
+                             const char *str, size_t len)
+{
+    res->u.data.what = DATA1I_text;
+    res->u.data.data = data1_insert_string_n(dh, res, m, str, len);
+    res->u.data.len = len;
+}
+
+void data1_set_data_string(data1_handle dh, data1_node *res, NMEM m,
+                           const char *str)
+{
+    data1_set_data_string_n(dh, res, m, str, strlen(str));
+}
+
+char *data1_insert_string_n(data1_handle dh, data1_node *res,
+                            NMEM m, const char *str, size_t len)
 {
     char *b;
     if (len >= DATA1_LOCALDATA)
-        b = (char *) nmem_malloc (m, len+1);
+        b = (char *) nmem_malloc(m, len+1);
     else
         b = res->lbuf;
-    memcpy (b, str, len);
+    memcpy(b, str, len);
     b[len] = 0;
     return b;
 }
 
-char *data1_insert_string (data1_handle dh, data1_node *res,
-                           NMEM m, const char *str)
+char *data1_insert_zint(data1_handle dh, data1_node *res, NMEM m, zint num)
 {
-    return data1_insert_string_n (dh, res, m, str, strlen(str));
+    char str[64];
+
+    yaz_snprintf(str, sizeof(str), ZINT_FORMAT, num);
+    return data1_insert_string(dh, res, m, str);
+}
+
+void data1_set_data_zint(data1_handle dh, data1_node *res, NMEM m, zint num)
+{
+    res->u.data.what = DATA1I_num;
+    res->u.data.data = data1_insert_zint(dh, res, m, num);
+    res->u.data.len = strlen(res->u.data.data);
+}
+
+char *data1_insert_string(data1_handle dh, data1_node *res,
+                          NMEM m, const char *str)
+{
+    return data1_insert_string_n(dh, res, m, str, strlen(str));
 }
 
 static data1_node *data1_add_insert_taggeddata(data1_handle dh,
@@ -396,28 +420,28 @@ static data1_node *data1_add_insert_taggeddata(data1_handle dh,
                                                int insert_mode)
 {
     data1_node *root = at->root;
-    data1_node *partag = get_parent_tag (dh, at);
+    data1_node *partag = get_parent_tag(dh, at);
     data1_element *e = NULL;
     data1_node *datn = 0;
     data1_node *tagn = 0;
 
     if (!partag)
-        e = data1_getelementbytagname (dh, root->u.root.absyn, 0, tagname);
+        e = data1_getelementbytagname(dh, root->u.root.absyn, 0, tagname);
     else
     {
         e = partag->u.tag.element;
         if (e)
-            e = data1_getelementbytagname (dh, root->u.root.absyn, e, tagname);
+            e = data1_getelementbytagname(dh, root->u.root.absyn, e, tagname);
     }
     if (local_allowed || e)
     {
         if (insert_mode)
-            tagn = data1_insert_node (dh, m, DATA1N_tag, at);
+            tagn = data1_insert_node(dh, m, DATA1N_tag, at);
         else
-            tagn = data1_append_node (dh, m, DATA1N_tag, at);
-        tagn->u.tag.tag = data1_insert_string (dh, tagn, m, tagname);
+            tagn = data1_append_node(dh, m, DATA1N_tag, at);
+        tagn->u.tag.tag = data1_insert_string(dh, tagn, m, tagname);
         tagn->u.tag.element = e;
-        datn = data1_mk_node2 (dh, m, DATA1N_data, tagn);
+        datn = data1_mk_node2(dh, m, DATA1N_data, tagn);
     }
     return datn;
 }
@@ -425,7 +449,7 @@ static data1_node *data1_add_insert_taggeddata(data1_handle dh,
 data1_node *data1_mk_tag_data(data1_handle dh, data1_node *at,
                               const char *tagname, NMEM m)
 {
-    return data1_add_insert_taggeddata (dh, at, tagname, m, 1, 0);
+    return data1_add_insert_taggeddata(dh, at, tagname, m, 1, 0);
 }
 
 
@@ -437,153 +461,101 @@ data1_node *data1_mk_tag_data(data1_handle dh, data1_node *at,
 data1_node *data1_mk_tag_data_wd(data1_handle dh, data1_node *at,
                                  const char *tagname, NMEM m)
 {
-    return data1_add_insert_taggeddata (dh, at, tagname, m, 0, 1);
+    return data1_add_insert_taggeddata(dh, at, tagname, m, 0, 1);
 }
 
-data1_node *data1_insert_taggeddata (data1_handle dh, data1_node *root,
-                                     data1_node *at, const char *tagname,
-                                     NMEM m)
+data1_node *data1_insert_taggeddata(data1_handle dh, data1_node *root,
+                                    data1_node *at, const char *tagname,
+                                    NMEM m)
 {
-    return data1_add_insert_taggeddata (dh, at, tagname, m, 0, 1);
+    return data1_add_insert_taggeddata(dh, at, tagname, m, 0, 1);
 }
 
-data1_node *data1_add_taggeddata (data1_handle dh, data1_node *root,
-                                  data1_node *at, const char *tagname,
-                                  NMEM m)
+data1_node *data1_add_taggeddata(data1_handle dh, data1_node *root,
+                                 data1_node *at, const char *tagname,
+                                 NMEM m)
 {
-    return data1_add_insert_taggeddata (dh, at, tagname, m, 1, 0);
+    return data1_add_insert_taggeddata(dh, at, tagname, m, 1, 0);
 }
 
-data1_node *data1_mk_tag_data_zint (data1_handle dh, data1_node *at,
+data1_node *data1_mk_tag_data_zint(data1_handle dh, data1_node *at,
                                    const char *tag, zint num,
                                    NMEM nmem)
 {
     data1_node *node_data;
 
-    node_data = data1_mk_tag_data (dh, at, tag, nmem);
+    node_data = data1_mk_tag_data(dh, at, tag, nmem);
     if (!node_data)
         return 0;
-    node_data->u.data.what = DATA1I_num;
-    node_data->u.data.data = node_data->lbuf;
-    sprintf (node_data->u.data.data, ZINT_FORMAT, num);
-    node_data->u.data.len = strlen (node_data->u.data.data);
+    data1_set_data_zint(dh, node_data, nmem, num);
     return node_data;
 }
 
-data1_node *data1_mk_tag_data_int (data1_handle dh, data1_node *at,
-                                   const char *tag, int num,
-                                   NMEM nmem)
+data1_node *data1_mk_tag_data_int(data1_handle dh, data1_node *at,
+                                  const char *tag, int num,
+                                  NMEM nmem)
 {
     return data1_mk_tag_data_zint(dh, at, tag, num, nmem);
 }
 
-data1_node *data1_mk_tag_data_oid (data1_handle dh, data1_node *at,
-                                   const char *tag, Odr_oid *oid,
-                                   NMEM nmem)
+data1_node *data1_mk_tag_data_oid(data1_handle dh, data1_node *at,
+                                  const char *tag, Odr_oid *oid,
+                                  NMEM nmem)
 {
     data1_node *node_data;
     char str[128], *p = str;
-    Odr_oid *ii;
+    size_t i;
 
-    node_data = data1_mk_tag_data (dh, at, tag, nmem);
+    node_data = data1_mk_tag_data(dh, at, tag, nmem);
     if (!node_data)
         return 0;
 
-    for (ii = oid; *ii >= 0; ii++)
+    for (i = 0; i < 14 && oid[i] >= 0; i++)
     {
-        if (ii != oid)
+        if (i > 0)
             *p++ = '.';
-        sprintf (p, "%d", *ii);
-        p += strlen (p);
+        yaz_snprintf(p, 7, "%d", oid[i]);
+        p += strlen(p);
     }
+    data1_set_data_string(dh, node_data, nmem, str);
     node_data->u.data.what = DATA1I_oid;
-    node_data->u.data.len = strlen (str);
-    node_data->u.data.data = data1_insert_string (dh, node_data, nmem, str);
     return node_data;
 }
 
 
-data1_node *data1_mk_tag_data_text (data1_handle dh, data1_node *at,
-                                    const char *tag, const char *str,
-                                    NMEM nmem)
+data1_node *data1_mk_tag_data_text(data1_handle dh, data1_node *at,
+                                   const char *tag, const char *str,
+                                   NMEM nmem)
 {
-    data1_node *node_data;
-
-    node_data = data1_mk_tag_data (dh, at, tag, nmem);
+    data1_node *node_data = data1_mk_tag_data(dh, at, tag, nmem);
     if (!node_data)
         return 0;
-    node_data->u.data.what = DATA1I_text;
-    node_data->u.data.len = strlen (str);
-    node_data->u.data.data = data1_insert_string (dh, node_data, nmem, str);
+    data1_set_data_string(dh, node_data, nmem, str);
     return node_data;
 }
 
 
-data1_node *data1_mk_tag_data_text_uni (data1_handle dh, data1_node *at,
-                                        const char *tag, const char *str,
-                                        NMEM nmem)
+data1_node *data1_mk_tag_data_text_uni(data1_handle dh, data1_node *at,
+                                       const char *tag, const char *str,
+                                       NMEM nmem)
 {
-    data1_node *node = data1_search_tag (dh, at->child, tag);
+    data1_node *node = data1_search_tag(dh, at->child, tag);
     if (!node)
-        return data1_mk_tag_data_text (dh, at, tag, str, nmem);
-    else
-    {
-        data1_node *node_data = node->child;
-        node_data->u.data.what = DATA1I_text;
-        node_data->u.data.len = strlen (str);
-        node_data->u.data.data = data1_insert_string (dh, node_data,
-                                                      nmem, str);
-        node_data->child = node_data->last_child = 0;
-        return node_data;
-    }
+        return data1_mk_tag_data_text(dh, at, tag, str, nmem);
+    node = node->child;
+    data1_set_data_string(dh, node, nmem, str);
+    node->child = node->last_child = 0;
+    return node;
 }
 
-static int ampr (int (*get_byte)(void *fh), void *fh, int *amp)
+static int ampr(int (*get_byte)(void *fh), void *fh, int *amp)
 {
-#if 1
     int c = (*get_byte)(fh);
     *amp = 0;
     return c;
-#else
-    int c = (*get_byte)(fh);
-    *amp = 0;
-    if (c == '&')
-    {
-        char ent[20];
-        int i = 0;
-
-        while (1)
-        {
-            c = (*get_byte)(fh);
-            if (c == ';')
-            {
-                ent[i] = 0;
-
-                c = ' ';
-                if (!strcmp (ent, "quot"))
-                    c = '"';
-                if (!strcmp (ent, "apos"))
-                    c = '\'';
-                if (!strcmp (ent, "gt"))
-                    c = '>';
-                if (!strcmp (ent, "lt"))
-                    c = '<';
-                if (!strcmp (ent, "amp"))
-                    c = '&';
-                *amp = 1;
-                break;
-            }
-            else if (c == 0 || d1_isspace(c))
-                break;
-            if (i < 19)
-                ent[i++] = c;
-        }
-    }
-    return c;
-#endif
 }
 
-data1_xattr *data1_read_xattr (data1_handle dh, NMEM m,
+data1_xattr *data1_read_xattr(data1_handle dh, NMEM m,
                                int (*get_byte)(void *fh), void *fh,
                                WRBUF wrbuf, int *ch, int *amp)
 {
@@ -594,10 +566,10 @@ data1_xattr *data1_read_xattr (data1_handle dh, NMEM m,
     {
         data1_xattr *p;
         while (*amp || (c && d1_isspace(c)))
-            c = ampr (get_byte, fh, amp);
+            c = ampr(get_byte, fh, amp);
         if (*amp == 0 && (c == 0 || c == '>' || c == '/'))
             break;
-        *pp = p = (data1_xattr *) nmem_malloc (m, sizeof(*p));
+        *pp = p = (data1_xattr *) nmem_malloc(m, sizeof(*p));
         p->next = 0;
         pp = &p->next;
         p->value = 0;
@@ -606,44 +578,44 @@ data1_xattr *data1_read_xattr (data1_handle dh, NMEM m,
         wrbuf_rewind(wrbuf);
         while (c && c != '=' && c != '>' && c != '/' && !d1_isspace(c))
         {
-            wrbuf_putc (wrbuf, c);
-            c = ampr (get_byte, fh, amp);
+            wrbuf_putc(wrbuf, c);
+            c = ampr(get_byte, fh, amp);
         }
-        p->name = nmem_strdup (m, wrbuf_cstr(wrbuf));
+        p->name = nmem_strdup(m, wrbuf_cstr(wrbuf));
         if (c == '=')
         {
-            c = ampr (get_byte, fh, amp);
+            c = ampr(get_byte, fh, amp);
             if (*amp == 0 && c == '"')
             {
-                c = ampr (get_byte, fh, amp);
+                c = ampr(get_byte, fh, amp);
                 wrbuf_rewind(wrbuf);
                 while (*amp || (c && c != '"'))
                 {
-                    wrbuf_putc (wrbuf, c);
-                    c = ampr (get_byte, fh, amp);
+                    wrbuf_putc(wrbuf, c);
+                    c = ampr(get_byte, fh, amp);
                 }
                 if (c)
-                    c = ampr (get_byte, fh, amp);
+                    c = ampr(get_byte, fh, amp);
             }
             else if (*amp == 0 && c == '\'')
             {
-                c = ampr (get_byte, fh, amp);
+                c = ampr(get_byte, fh, amp);
                 wrbuf_rewind(wrbuf);
                 while (*amp || (c && c != '\''))
                 {
-                    wrbuf_putc (wrbuf, c);
-                    c = ampr (get_byte, fh, amp);
+                    wrbuf_putc(wrbuf, c);
+                    c = ampr(get_byte, fh, amp);
                 }
                 if (c)
-                    c = ampr (get_byte, fh, amp);
+                    c = ampr(get_byte, fh, amp);
             }
             else
             {
                 wrbuf_rewind(wrbuf);
                 while (*amp || (c && c != '>' && c != '/'))
                 {
-                    wrbuf_putc (wrbuf, c);
-                    c = ampr (get_byte, fh, amp);
+                    wrbuf_putc(wrbuf, c);
+                    c = ampr(get_byte, fh, amp);
                 }
             }
             p->value = nmem_strdup(m, wrbuf_cstr(wrbuf));
@@ -657,7 +629,7 @@ data1_xattr *data1_read_xattr (data1_handle dh, NMEM m,
  * Ugh. Sometimes functions just grow and grow on you. This one reads a
  * 'node' and its children.
  */
-data1_node *data1_read_nodex (data1_handle dh, NMEM m,
+data1_node *data1_read_nodex(data1_handle dh, NMEM m,
                               int (*get_byte)(void *fh), void *fh, WRBUF wrbuf)
 {
     data1_node *d1_stack[256];
@@ -667,7 +639,7 @@ data1_node *data1_read_nodex (data1_handle dh, NMEM m,
     int line = 1;
 
     d1_stack[level] = 0;
-    c = ampr (get_byte, fh, &amp);
+    c = ampr(get_byte, fh, &amp);
     while (c != '\0')
     {
         data1_node *parent = level ? d1_stack[level-1] : 0;
@@ -681,11 +653,11 @@ data1_node *data1_read_nodex (data1_handle dh, NMEM m,
             int end_tag = 0;
             size_t i = 0;
 
-            c = ampr (get_byte, fh, &amp);
+            c = ampr(get_byte, fh, &amp);
             if (amp == 0 && c == '/')
             {
                 end_tag = 1;
-                c = ampr (get_byte, fh, &amp);
+                c = ampr(get_byte, fh, &amp);
             }
             else if (amp == 0 && c == '?')
             {
@@ -720,17 +692,17 @@ data1_node *data1_read_nodex (data1_handle dh, NMEM m,
 
                 wrbuf_rewind(wrbuf);
 
-                c0 = ampr (get_byte, fh, &amp0);
+                c0 = ampr(get_byte, fh, &amp0);
                 if (amp0 == 0 && c0 == '\0')
                     break;
-                c = ampr (get_byte, fh, &amp);
+                c = ampr(get_byte, fh, &amp);
 
                 if (amp0 == 0 && c0 == '-' && amp == 0 && c == '-')
                 {
                     /* COMMENT: <!-- ... --> */
                     int no_dash = 0;
 
-                    c = ampr (get_byte, fh, &amp);
+                    c = ampr(get_byte, fh, &amp);
                     while (amp || c)
                     {
                         if (amp == 0 && c == '-')
@@ -739,17 +711,17 @@ data1_node *data1_read_nodex (data1_handle dh, NMEM m,
                         {
                             if (level > 0)
                                 d1_stack[level] =
-                                    data1_mk_comment_n (
+                                    data1_mk_comment_n(
                                         dh, m,
                                         wrbuf_buf(wrbuf), wrbuf_len(wrbuf)-2,
                                         d1_stack[level-1]);
-                            c = ampr (get_byte, fh, &amp); /* skip > */
+                            c = ampr(get_byte, fh, &amp); /* skip > */
                             break;
                         }
                         else
                             no_dash = 0;
-                        wrbuf_putc (wrbuf, c);
-                        c = ampr (get_byte, fh, &amp);
+                        wrbuf_putc(wrbuf, c);
+                        c = ampr(get_byte, fh, &amp);
                     }
                     continue;
                 }
@@ -761,14 +733,14 @@ data1_node *data1_read_nodex (data1_handle dh, NMEM m,
                     {
                         if (amp == 0 && c == '>' && blevel == 0)
                         {
-                            c = ampr (get_byte, fh, &amp);
+                            c = ampr(get_byte, fh, &amp);
                             break;
                         }
                         if (amp == 0 && c == '[')
                             blevel++;
                         if (amp == 0 && c == ']' && blevel > 0)
                             blevel--;
-                        c = ampr (get_byte, fh, &amp);
+                        c = ampr(get_byte, fh, &amp);
                     }
                     continue;
                 }
@@ -777,14 +749,14 @@ data1_node *data1_read_nodex (data1_handle dh, NMEM m,
             {
                 if (i < (sizeof(tag)-1))
                     tag[i++] = c;
-                c = ampr (get_byte, fh, &amp);
+                c = ampr(get_byte, fh, &amp);
             }
             tag[i] = '\0';
-            xattr = data1_read_xattr (dh, m, get_byte, fh, wrbuf, &c, &amp);
+            xattr = data1_read_xattr(dh, m, get_byte, fh, wrbuf, &c, &amp);
             if (amp == 0 && c == '/')
             {    /* <tag attrs/> or <tag/> */
                 null_tag = 1;
-                c = ampr (get_byte, fh, &amp);
+                c = ampr(get_byte, fh, &amp);
             }
             if (amp || c != '>')
             {
@@ -792,7 +764,7 @@ data1_node *data1_read_nodex (data1_handle dh, NMEM m,
                 return 0;
             }
             else
-                c = ampr (get_byte, fh, &amp);
+                c = ampr(get_byte, fh, &amp);
 
             /* End tag? */
             if (end_tag)
@@ -816,7 +788,7 @@ data1_node *data1_read_nodex (data1_handle dh, NMEM m,
                     }
                     if (i != level)
                     {
-                        yaz_log (YLOG_WARN, "%d: no begin tag for %s",
+                        yaz_log(YLOG_WARN, "%d: no begin tag for %s",
                                  line, tag);
                         break;
                     }
@@ -858,7 +830,7 @@ data1_node *data1_read_nodex (data1_handle dh, NMEM m,
                  */
                 if (parent->which != DATA1N_variant)
                 {
-                    res = data1_mk_node2 (dh, m, DATA1N_variant, parent);
+                    res = data1_mk_node2(dh, m, DATA1N_variant, parent);
                 }
                 else
                 {
@@ -873,10 +845,10 @@ data1_node *data1_read_nodex (data1_handle dh, NMEM m,
                             level = i;
                             break;
                         }
-                    res = data1_mk_node2 (dh, m, DATA1N_variant, parent);
+                    res = data1_mk_node2(dh, m, DATA1N_variant, parent);
                     res->u.variant.type = tp;
                     res->u.variant.value =
-                        data1_insert_string (dh, res, m, value);
+                        data1_insert_string(dh, res, m, value);
                 }
             }
             else
@@ -885,19 +857,19 @@ data1_node *data1_read_nodex (data1_handle dh, NMEM m,
                 /* tag .. acquire our element in the abstract syntax */
                 if (level == 0)
                 {
-                    parent = data1_mk_root (dh, m, tag);
+                    parent = data1_mk_root(dh, m, tag);
                     res = d1_stack[level] = parent;
 
                     if (data1_is_xmlmode(dh))
                     {
                         level++;
-                        res = data1_mk_tag (dh, m, tag, 0 /* attr */, parent);
+                        res = data1_mk_tag(dh, m, tag, 0 /* attr */, parent);
                         res->u.tag.attributes = xattr;
                     }
                 }
                 else
                 {
-                    res = data1_mk_tag (dh, m, tag, 0 /* attr */, parent);
+                    res = data1_mk_tag(dh, m, tag, 0 /* attr */, parent);
                     res->u.tag.attributes = xattr;
                 }
             }
@@ -912,10 +884,10 @@ data1_node *data1_read_nodex (data1_handle dh, NMEM m,
 
             if (level == 0)
             {
-                c = ampr (get_byte, fh, &amp);
+                c = ampr(get_byte, fh, &amp);
                 continue;
             }
-            res = data1_mk_node2 (dh, m, DATA1N_data, parent);
+            res = data1_mk_node2(dh, m, DATA1N_data, parent);
             res->u.data.what = DATA1I_xmltext;
             res->u.data.formatted_text = 0;
             d1_stack[level] = res;
@@ -924,19 +896,19 @@ data1_node *data1_read_nodex (data1_handle dh, NMEM m,
 
             while (amp || (c && c != '<'))
             {
-                wrbuf_putc (wrbuf, c);
-                c = ampr (get_byte, fh, &amp);
+                wrbuf_putc(wrbuf, c);
+                c = ampr(get_byte, fh, &amp);
             }
             len = wrbuf_len(wrbuf);
 
             /* use local buffer of nmem if too large */
             if (len >= DATA1_LOCALDATA)
-                res->u.data.data = (char*) nmem_malloc (m, len);
+                res->u.data.data = (char*) nmem_malloc(m, len);
             else
                 res->u.data.data = res->lbuf;
 
             if (len)
-                memcpy (res->u.data.data, wrbuf_buf(wrbuf), len);
+                memcpy(res->u.data.data, wrbuf_buf(wrbuf), len);
             else
                 res->u.data.data = 0;
             res->u.data.len = len;
@@ -945,7 +917,7 @@ data1_node *data1_read_nodex (data1_handle dh, NMEM m,
     return 0;
 }
 
-int getc_mem (void *fh)
+int getc_mem(void *fh)
 {
     const char **p = (const char **) fh;
     if (**p)
@@ -953,7 +925,7 @@ int getc_mem (void *fh)
     return 0;
 }
 
-data1_node *data1_read_node (data1_handle dh, const char **buf, NMEM m)
+data1_node *data1_read_node(data1_handle dh, const char **buf, NMEM m)
 {
     WRBUF wrbuf = wrbuf_alloc();
     data1_node *node;
@@ -971,7 +943,7 @@ data1_node *data1_read_record(data1_handle dh,
                               NMEM m)
 {
     int *size;
-    char **buf = data1_get_read_buf (dh, &size);
+    char **buf = data1_get_read_buf(dh, &size);
     const char *bp;
     int rd = 0, res;
 
@@ -997,10 +969,10 @@ data1_node *data1_read_record(data1_handle dh,
     }
 }
 
-data1_node *data1_read_sgml (data1_handle dh, NMEM m, const char *buf)
+data1_node *data1_read_sgml(data1_handle dh, NMEM m, const char *buf)
 {
     const char *bp = buf;
-    return data1_read_node (dh, &bp, m);
+    return data1_read_node(dh, &bp, m);
 }
 
 
@@ -1013,7 +985,7 @@ static int conv_item(NMEM m, yaz_iconv_t t,
     return 0;
 }
 
-static void data1_iconv_s (data1_handle dh, NMEM m, data1_node *n,
+static void data1_iconv_s(data1_handle dh, NMEM m, data1_node *n,
                            yaz_iconv_t t, WRBUF wrbuf, const char *tocode)
 {
     for (; n; n = n->next)
@@ -1022,21 +994,19 @@ static void data1_iconv_s (data1_handle dh, NMEM m, data1_node *n,
         {
         case DATA1N_data:
         case DATA1N_comment:
-            if (conv_item (m, t, wrbuf, n->u.data.data, n->u.data.len) == 0)
+            if (conv_item(m, t, wrbuf, n->u.data.data, n->u.data.len) == 0)
             {
                 n->u.data.data =
-                    data1_insert_string_n (dh, n, m, wrbuf->buf,
-                                           wrbuf->pos);
+                    data1_insert_string_n(dh, n, m, wrbuf->buf, wrbuf->pos);
                 n->u.data.len = wrbuf->pos;
             }
             break;
         case DATA1N_tag:
-            if (conv_item (m, t, wrbuf, n->u.tag.tag, strlen(n->u.tag.tag))
+            if (conv_item(m, t, wrbuf, n->u.tag.tag, strlen(n->u.tag.tag))
                 == 0)
             {
                 n->u.tag.tag =
-                    data1_insert_string_n (dh, n, m,
-                                           wrbuf->buf, wrbuf->pos);
+                    data1_insert_string_n(dh, n, m, wrbuf->buf, wrbuf->pos);
             }
             if (n->u.tag.attributes)
             {
@@ -1057,24 +1027,24 @@ static void data1_iconv_s (data1_handle dh, NMEM m, data1_node *n,
             {
                 data1_xattr *p = n->u.preprocess.attributes;
                 for (; p; p = p->next)
-                    if (strcmp (p->name, "encoding") == 0)
-                        p->value = nmem_strdup (m, tocode);
+                    if (strcmp(p->name, "encoding") == 0)
+                        p->value = nmem_strdup(m, tocode);
             }
             break;
         }
-        data1_iconv_s (dh, m, n->child, t, wrbuf, tocode);
+        data1_iconv_s(dh, m, n->child, t, wrbuf, tocode);
     }
 }
 
-const char *data1_get_encoding (data1_handle dh, data1_node *n)
+const char *data1_get_encoding(data1_handle dh, data1_node *n)
 {
     /* see if we have an xml header that specifies encoding */
     if (n && n->child && n->child->which == DATA1N_preprocess &&
-        strcmp (n->child->u.preprocess.target, "xml") == 0)
+        strcmp(n->child->u.preprocess.target, "xml") == 0)
     {
         data1_xattr *xp = n->child->u.preprocess.attributes;
         for (; xp; xp = xp->next)
-            if (strcmp (xp->name, "encoding") == 0)
+            if (strcmp(xp->name, "encoding") == 0)
                 return xp->value;
     }
     /* no encoding in header, so see if "encoding" was specified for abs */
@@ -1085,11 +1055,11 @@ const char *data1_get_encoding (data1_handle dh, data1_node *n)
     return "ISO-8859-1";
 }
 
-int data1_iconv (data1_handle dh, NMEM m, data1_node *n,
+int data1_iconv(data1_handle dh, NMEM m, data1_node *n,
                  const char *tocode,
                  const char *fromcode)
 {
-    if (yaz_matchstr (tocode, fromcode))
+    if (yaz_matchstr(tocode, fromcode))
     {
         WRBUF wrbuf = wrbuf_alloc();
         yaz_iconv_t t = yaz_iconv_open(tocode, fromcode);
