@@ -27,12 +27,11 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #include <yaz/log.h>
 #include <idzebra/data1.h>
 
-
-void data1_remove_node (data1_handle dh, data1_node *n)
+void data1_remove_node(data1_handle dh, data1_node *n)
 {
-    fprintf (stdout, "REMOVE tag %s \n", n->u.tag.tag);
     /* n is first childen */
-    if(n->parent->child == n){
+    if (n->parent->child == n)
+    {
         n->parent->child = n->next;
 
         /* n is the only child */
@@ -41,7 +40,8 @@ void data1_remove_node (data1_handle dh, data1_node *n)
         }
     }
     /* n is one of the following childrens */
-    else {
+    else
+    {
         data1_node * before;
 
         /* need to find sibling before me */
@@ -52,9 +52,8 @@ void data1_remove_node (data1_handle dh, data1_node *n)
         before->next = n->next;
 
         /* n is last child of many */
-        if ( n->parent->last_child == n){
+        if ( n->parent->last_child == n)
             n->parent->last_child = before;
-        }
     }
     /* break pointers to root, parent and following siblings */
     n->parent = 0;
@@ -62,59 +61,26 @@ void data1_remove_node (data1_handle dh, data1_node *n)
     n->next = 0;
 }
 
-void data1_remove_idzebra_subtree (data1_handle dh, data1_node *n)
+void data1_remove_idzebra_subtree(data1_handle dh, data1_node *n)
 {
-    switch (n->which)
+    if (n->which == DATA1N_tag && !strcmp(n->u.tag.tag, "idzebra")
+        && n->u.tag.attributes)
+    {
+        data1_xattr *xattr = n->u.tag.attributes;
+
+        for (; xattr; xattr = xattr->next)
         {
-            /*
-        case DATA1N_root:
-            break;
-            */
-        case DATA1N_tag:
-            if (!strcmp(n->u.tag.tag, "idzebra")){
-                if (n->u.tag.attributes){
-                    data1_xattr *xattr = n->u.tag.attributes;
-
-                    for (; xattr; xattr = xattr->next){
-                        if (!strcmp(xattr->name, "xmlns")
-                            & !strcmp(xattr->value,
-                                      "http://www.indexdata.dk/zebra/"))
-                            data1_remove_node (dh, n);
-                    }
-                }
-            }
-
-            break;
-            /*
-        case DATA1N_data:
-            break;
-        case DATA1N_comment:
-            break;
-        case DATA1N_preprocess:
-            break;
-        case DATA1N_variant:
-        break;
-            */
-        default:
-            break;
+            if (!strcmp(xattr->name, "xmlns")
+                && !strcmp(xattr->value, "http://www.indexdata.dk/zebra/"))
+                data1_remove_node(dh, n);
         }
+    }
     if (n->child)
-        data1_remove_idzebra_subtree (dh, n->child);
+        data1_remove_idzebra_subtree(dh, n->child);
     if (n->next)
-        data1_remove_idzebra_subtree (dh, n->next);
-    /*
-    else
-        {
-            if (n->parent && n->parent->last_child != n)
-                fprintf(out, "%*sWARNING: last_child=%p != %p\n", level, "",
-                        n->parent->last_child, n);
-        }
-    */
-
+        data1_remove_idzebra_subtree(dh, n->next);
 }
 
-
-
 /*
  * Local variables:
  * c-basic-offset: 4
